# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   test_56
# FileName:      read_excel.py
# Author:       xxxxxxx
# Datetime:     2023/8/7 15:29
# Description:
# 
# ---------------------------------------------------------------------------
import openpyxl

from InterfaceAutoTest.common.read_ini import ReadIni
from InterfaceAutoTest.common.read_json import read_json


class ReadExcel:
    def __init__(self):
        """读取数据配置层中所有文件，除了ini文件"""
        self.read_ini = ReadIni()

        case_data_path = self.read_ini.get_file_path("case")
        expect_data_path = self.read_ini.get_file_path("expect")
        sql_data_path = self.read_ini.get_file_path("sql")

        self.case_data_dict = read_json(case_data_path)
        self.expect_data_dict = read_json(expect_data_path)
        self.sql_data_dict = read_json(sql_data_path)

        excel_path = self.read_ini.get_file_path("excel")
        wb = openpyxl.load_workbook(excel_path)
        self.ws = wb[self.read_ini.get_table_name("table")]

    def __get_cell_value(self, column: str, row: int) -> str:
        value = self.ws[str(column)+str(row)].value

        if value is None:
            return None
        elif value.strip():
            return value.strip()

    def module_name(self, row):
        return self.__get_cell_value("B", row)

    def interface_name(self, row):
        return self.__get_cell_value("c", row)

    def case_title(self, row):
        return self.__get_cell_value("D", row)

    def case_level(self, row):
        return self.__get_cell_value("E", row)

    def case_method(self, row):
        return self.__get_cell_value("F", row)

    def case_url(self, row):
        host = self.read_ini.get_host("test_bpm")

        return host+self.__get_cell_value("G", row)

    def case_mime(self, row):
        value = self.__get_cell_value("H", row)

        if value:
            return value.lower()

    def case_data(self, row):
        case_data_key = self.__get_cell_value("i", row)
        if case_data_key:
            module_name = self.module_name(row)
            interface_name = self.interface_name(row)
            return self.case_data_dict[module_name][interface_name][case_data_key]

    def expect_data(self, row):
        expect_data_key = self.__get_cell_value("j", row)
        if expect_data_key:
            module_name = self.module_name(row)
            interface_name = self.interface_name(row)
            return self.expect_data_dict[module_name][interface_name][expect_data_key]

    def sql_type(self, row):
        value = self.__get_cell_value("k", row)
        if value:
            return value.lower()

    def sql_sentence(self, row):
        sql_data_key = self.__get_cell_value("l", row)
        if sql_data_key:
            module_name = self.module_name(row)
            interface_name = self.interface_name(row)
            return self.sql_data_dict[module_name][interface_name][sql_data_key]

    def update_key(self, row):
        return self.__get_cell_value("m", row)

    def get_data(self):
        list_data = []
        for row in range(2, self.ws.max_row+1):
            module = self.module_name(row)
            interface = self.interface_name(row)
            title = self.case_title(row)
            level = self.case_level(row)
            method = self.case_method(row)
            url = self.case_url(row)
            mime = self.case_mime(row)
            data = self.case_data(row)
            expect = self.expect_data(row)
            sql_type = self.sql_type(row)
            sql_sentence = self.sql_sentence(row)
            update_key = self.update_key(row)
            list_data.append([module, interface, title, level, method, url, mime, data, expect, sql_type, sql_sentence, update_key])
        else:
            return list_data


if __name__ == '__main__':
    read_excel = ReadExcel()
    print(read_excel.get_data())




